resolve_tilde library

Support for resolve_tilde.

This library contains a top-level tilde variable that is the constant string of '~' and a Tilde class for the functions.

Classes

Tilde
The main class for resolving tildes. This class cannot be instantiated.

Constants

tilde → const String
Constant string of '~'.

Exceptions / Errors

HomeDirectoryNotFoundException
This exception is called when the resolver cannot find a home directory through the several methods used. This exception doesn't have a specific message, but instead uses the list reasons to gather every single reason that went wrong, then turn that into the message variable.