Tilde class
The main class for resolving tildes. This class cannot be instantiated.
tilde is a constant string of '~', exactly like the top-level tilde variable.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
[String path = tilde]) → String -
Resolve a tilde in the specified
pathargument.pathdefaults to just a tilde. If the included path does not start with a tilde, then the path is just returned as-is. -
resolveOrNull(
[String path = tilde]) → String? -
Resolve a tilde in the specified
pathargument.pathdefaults to just a tilde. If the included path does not start with a tilde, then the path is just returned as-is. This function is the same as resolve, but instead of throwing a HomeDirectoryNotFoundException when it cannot find a home directory, it returns null.